% These scripts perform the d analysis for stimulation using an optical fiber, 
% different datasets can be chosen by (un)commenting the variable files2analyze) in the beginning of the script. 
% Correspondingly, the line save with the corresponding filename to be saved needs to be uncommented at the end of each script, 
% in order to save the analysis of different datasets with different filenames. 
% The saved files will later be called in different scripts. 

clear all; close all; clc;

%% hearing animals
%  files2analyze= {  'E:\projects\paper_uLED\revision\data\data_IC_MUA_opto\01_optical_fiber\hearing\gad633_0002_Resort';
%                     'E:\projects\paper_uLED\revision\data\data_IC_MUA_opto\01_optical_fiber\hearing\gad791_0002_Resort';
%                     'E:\projects\paper_uLED\revision\data\data_IC_MUA_opto\01_optical_fiber\hearing\gad757_0003_Resort';
%                     'E:\projects\paper_uLED\revision\data\data_IC_MUA_opto\01_optical_fiber\hearing\gad730_0003_Resort';
%                     'E:\projects\paper_uLED\revision\data\data_IC_MUA_opto\01_optical_fiber\hearing\gad732_0003_Resort';
%                     'E:\projects\paper_uLED\revision\data\data_IC_MUA_opto\01_optical_fiber\hearing\gad731_0003_Resort';
%                     'E:\projects\paper_uLED\revision\data\data_IC_MUA_opto\01_optical_fiber\hearing\gad815_0002_Resort';
%                     'E:\projects\paper_uLED\revision\data\data_IC_MUA_opto\01_optical_fiber\hearing\1142_0003_Resort';
%                     'E:\projects\paper_uLED\revision\data\data_IC_MUA_opto\01_optical_fiber\hearing\gad1200_0002_Resort'};
 

%% deaf animals
% files2analyze = {  'E:\projects\paper_uLED\revision\data\data_IC_MUA_opto\01_optical_fiber\deafened\gad1093_0002_Resort';
%                    'E:\projects\paper_uLED\revision\data\data_IC_MUA_opto\01_optical_fiber\deafened\GAD841_0002_Resort';
%                    'E:\projects\paper_uLED\revision\data\data_IC_MUA_opto\01_optical_fiber\deafened\gad1113_0002_Resort'};


%% start and stop of time window to analyze spikerate and electrodes to analyze (32 electrode array)
spikewindow_start = 0.003; spikewindow_stop = 0.020; % in seconds
n_electrodes = 32; % 32 channel electrode array
all_electrodes = [1:n_electrodes]-1; 

DprimeThreshold = 1;

%% read out matrix of firing rate per stimulus per electrode for each animal and compute the cumulative d' values of this data
for aa = 1:size(files2analyze, 1)
    
    curFileName = files2analyze{aa, 1};
    [animal_ID, unit_depth, track_number, exp_type]    =   getInfo(curFileName);
    all_IDs{aa} = animal_ID; all_depths(aa) = unit_depth;
    load(curFileName);
    
    tEvalWin = [spikewindow_start, spikewindow_stop];
    Lvl = Header.stimlist(:, 1);  [sortLvl, iSortLvl] = sort(Lvl);
    
    %initiate variables
    all_DprimeMats = zeros(length(all_electrodes), length(Lvl)-1);
    
    % go over all electrodes
    for yy = 1:length(all_electrodes)...
            curElectrode = all_electrodes(yy);
        icurElectrode = find(Spik_list(:,4) == curElectrode); cur_Spik_list = Spik_list(icurElectrode,:);
        un_stim = unique(Spik_list(:,1));
        
        StimResp = cell(Header.ncond,1);
        RespRate = zeros(Header.ncond,3);
        RespRate(:) = NaN;
        
        %...and all intensities
        for curStim = 1:size(un_stim,1);
            
            nRepCurStim = unique(Header.n_rep);
            RespDummyRate = zeros(1,nRepCurStim);
            for curRep = 1:nRepCurStim
                nSpikesInResp = sum(cur_Spik_list(:,1) == un_stim(curStim,1) & cur_Spik_list(:,2) == curRep & cur_Spik_list(:,6) > tEvalWin(1) & cur_Spik_list(:,6) <= tEvalWin(2) );
                RespDummyRate(curRep) = nSpikesInResp./diff(tEvalWin);
            end
            StimResp{curStim} = RespDummyRate;
            RespRate(curStim,1:3) = [mean(RespDummyRate),std(RespDummyRate),nRepCurStim];
        end
        
        % perform ROC analysis
        nComp = size(un_stim,1)-1;
        colorMat = jet(nComp);
        DprimeMat = zeros(nComp,1);
        ROC      = cell(nComp,1);
        AUCMat   = zeros(nComp,2);
        
        for curStimComp = 1:nComp;
            N = StimResp{iSortLvl(curStimComp)};
            P = StimResp{iSortLvl(curStimComp+1)};
            
            [ROCmat, AUC, Dprime, SE] = ROCAna_02(N, P, 0);
            DprimeMat(curStimComp,1) = Dprime;
            AUCMat(curStimComp,1:2) = [AUC, SE];
            ROC{curStimComp,1} = ROCmat;
        end
        
        % get Dprime threshold
        CumulativeDprimeMat = NaN(size(DprimeMat));
        iAboveThreshold = find(DprimeMat >= DprimeThreshold ,1, 'first');
        all_DprimeMats(yy, :)           = DprimeMat;
        
    end
    
    % save data of all iterations in a common variable
    all_Dprimes_cumsum_across_animals(:, :, aa) = cumsum(all_DprimeMats, 2);
    
end



%% the variable "all_Dprimes_cumsum_across_animals" contains all d prime values for all animals. Now you can use this to do further calculations
% analyze spatial spread for individual animals
for xx = 1:size(all_Dprimes_cumsum_across_animals, 3)
    clear s
    cur_data = all_Dprimes_cumsum_across_animals(:, :, xx);
    
    f1 = figure('color', [1 1 1], 'units','normalized','position',[.1 .1 0.35 .7]);
    
    title(['cumulative d' sprintf( '\''' ) '-values']);
    clear contour_matrix contour_lines
    [contour_matrix, ~] = contourf(unique(Header.stimlist(2:end, 1)),1:n_electrodes,cur_data,[DprimeThreshold DprimeThreshold]); 
    if any(contour_matrix)
    contour_lines = getcontourlines(contour_matrix); % define contour lines at this stage (for threshold at dprime = x)
    else
    contour_lines = [];
    end
    
    contourf(unique(Header.stimlist(2:end, 1)),1:n_electrodes,cur_data, [floor(min(min(cur_data))):1:ceil(max(max(cur_data)))]); hold on;
    c = colorbar; caxis([-1 6]); set(c,'XTick',[-1:1:6]); colormap gray;
    ylabel(c, ['d' sprintf( '\''' ) '-value']); cur_cmap = get(f1,'Colormap'); set(f1,'Colormap',flipud(cur_cmap));
    
    % get thresholds (based on open contour lines)
    i_threshold = 0; thresholds = {};
    
        for zz = 1:size(contour_lines, 2);
            if (contour_lines(zz).x(1) == contour_lines(zz).x(end) && contour_lines(zz).y(1) == contour_lines(zz).y(end)) | sum(contour_lines(zz).x == 1) > 0 % contour is closed
            else
                
                plot(contour_lines(zz).x, contour_lines(zz).y, 'b', 'linewidth', 1) ;           % contour is open
                i_threshold = i_threshold + 1;
                thresholds(i_threshold).x = contour_lines(zz).x; thresholds(i_threshold).y = contour_lines(zz).y;
                
            end
        end
    
    
    set(gca,'YTick', [2:2:n_electrodes], 'YtickLabel', [2:2:n_electrodes], 'Xtick', [1:2:33], 'Xticklabel',  [1:2:33]);
    xlabel('LaserIntensity [mW]'); ylabel('Electrode #');set(gca,'Ydir','reverse')
    
    channels = [1:n_electrodes]';
    thresholds_by_channel = zeros(1, n_electrodes)';
    
    for yy = 1:size(thresholds, 2)
        cur_thresholds = thresholds(yy);
        for ii = 1:size(channels)
            cur_channel = channels(ii);
            if nnz(ismember(cur_thresholds.y, cur_channel)) > 0
                idx_threshold = find(ismember(cur_thresholds.y, cur_channel));
                cur_threshold = cur_thresholds.x(idx_threshold);
                
                if length(cur_threshold) > 1
                    [minval, minloc] = min(cur_threshold);
                    cur_threshold = cur_threshold(minloc);
                    thresholds_by_channel(cur_channel) = cur_threshold;
                else
                    thresholds_by_channel(cur_channel) = cur_threshold;
                end
            end
        end
    end
    
    
    threshold_cutoff = Lvl(end-2);
    thresholds_by_channel(thresholds_by_channel > threshold_cutoff) = NaN; % blank channels below threshold
    thresholds_by_channel(thresholds_by_channel == 0) = NaN; % blank channels below threshold
    abs_thresholds(xx, :) = thresholds_by_channel;
    plot(thresholds_by_channel(~isnan(thresholds_by_channel)), channels(~isnan(thresholds_by_channel)), 'b*')
end


% define output variable
analysis_part_02_metadata.IDs = all_IDs;
analysis_part_02_metadata.thresholds = abs_thresholds;
analysis_part_02_metadata.dprime_cumsum = all_Dprimes_cumsum_across_animals;


%% uncomment the following line in order to actually save the output
% save (['STCs_Laser_3to20ms_hearing.mat'], 'analysis_part_02_metadata')
% save (['STCs_Laser_3to20ms_deaf.mat'], 'analysis_part_02_metadata')

