% This script plots the results of the scripts 03a-d. 
% Besides visualizing these results, the script also performs statistical analysis to compare response characteristics 
% between hearing and deafened animals (t-tests), thresholds of fiber- vs LED-stimulation (ranksum), 
% and the increase in response strengths and number of active electrodes for different stimulation modes (anova and multiple comparisons). 
% These values can be displayed in the command window. 

clear all; close all; clc;

% all hearing animals
path_base = 'E:\projects\paper_uLED\revision\analysis_final\';

uLEDs_indiv = load([path_base,  '03d_STC_indiv_LEDs\STCs_uLED_individual_3to20ms_hearing']);
uLEDs_block = load([path_base,  '03c_STC_block_LEDs\STCs_uLED_blockwise_3to20ms_hearing']);
all_uLEDs = load([path_base,  '03b_STC_all_LEDs\STCs_uLED_all_3to20ms_hearing']);
all_uLED_optical_fiber = load([path_base,  '03a_STC_fiber\STCs_Laser_3to20ms_hearing']);

% all deaf animals
uLEDs_indiv_deaf = load([path_base,  '03d_STC_indiv_LEDs\STCs_uLED_individual_3to20ms_deaf']);
uLEDs_block_deaf = load([path_base,  '03c_STC_block_LEDs\STCs_uLED_blockwise_3to20ms_deaf']);
all_uLEDs_deaf = load([path_base,  '03b_STC_all_LEDs\STCs_uLED_all_3to20ms_deaf']);
all_uLED_optical_fiber_deaf = load([path_base,  '03a_STC_fiber\STCs_Laser_3to20ms_deaf']);

% wildtype controls
all_uLEDs_wildtype = load([path_base,  '03b_STC_all_LEDs\STCs_uLED_all_3to20ms_wildtype_hearing']);
uLEDs_deaf_wildtype = load([path_base,  '03b_STC_all_LEDs\STCs_uLED_all_3to20ms_wildtype_deaf']);

% sacrificed controls
all_uLEDs_sacrificed = load([path_base,  '03b_STC_all_LEDs\STCs_uLED_all_3to20ms_hearing_sacrificed']);
all_uLEDs_sacrificed_deaf = load([path_base,  '03b_STC_all_LEDs\STCs_uLED_all_3to20ms_deaf_sacrificed']);


%% individual LEDs
% hearing
max_resp_indiv_uLEDs = []; active_electrodes_indiv = [];
for n_STC = 1:size(uLEDs_indiv.analysis_part_02_metadata.dprime_cumsum, 3)
    if sum(~isnan(uLEDs_indiv.analysis_part_02_metadata.thresholds(n_STC, :))) > 0
        max_resp_indiv_uLEDs = vertcat(max_resp_indiv_uLEDs, max(max(uLEDs_indiv.analysis_part_02_metadata.dprime_cumsum(:, :, n_STC))));
        active_electrodes_indiv = vertcat(active_electrodes_indiv, sum(~isnan(uLEDs_indiv.analysis_part_02_metadata.thresholds(n_STC, :)), 2));     
    end
end

% deaf
max_resp_indiv_uLEDs_deaf = []; active_electrodes_indiv_deaf = [];
for n_STC = 1:size(uLEDs_indiv_deaf.analysis_part_02_metadata.dprime_cumsum, 3)
    if sum(~isnan(uLEDs_indiv_deaf.analysis_part_02_metadata.thresholds(n_STC, :))) > 0
        max_resp_indiv_uLEDs_deaf = vertcat(max_resp_indiv_uLEDs_deaf, max(max(uLEDs_indiv_deaf.analysis_part_02_metadata.dprime_cumsum(:, :, n_STC))));
        active_electrodes_indiv_deaf = vertcat(active_electrodes_indiv_deaf, sum(~isnan(uLEDs_indiv_deaf.analysis_part_02_metadata.thresholds(n_STC, :)), 2));     
    end
end



%% blockwise uLEDs
% hearing
max_resp_block_uLEDs = []; active_electrodes_block = [];
for n_STC = 1:size(uLEDs_block.analysis_part_02_metadata.dprime_cumsum, 3)
    if sum(~isnan(uLEDs_block.analysis_part_02_metadata.thresholds(n_STC, :))) > 0
        max_resp_block_uLEDs = vertcat(max_resp_block_uLEDs, max(max(uLEDs_block.analysis_part_02_metadata.dprime_cumsum(:, :, n_STC))));
        active_electrodes_block = vertcat(active_electrodes_block, sum(~isnan(uLEDs_block.analysis_part_02_metadata.thresholds(n_STC, :)), 2));     
    end
end

% deaf
max_resp_block_uLEDs_deaf = []; active_electrodes_block_deaf = [];
for n_STC = 1:size(uLEDs_block_deaf.analysis_part_02_metadata.dprime_cumsum, 3)
    if sum(~isnan(uLEDs_block_deaf.analysis_part_02_metadata.thresholds(n_STC, :))) > 0
        max_resp_block_uLEDs_deaf = vertcat(max_resp_block_uLEDs_deaf, max(max(uLEDs_block_deaf.analysis_part_02_metadata.dprime_cumsum(:, :, n_STC))));
        active_electrodes_block_deaf = vertcat(active_electrodes_block_deaf, sum(~isnan(uLEDs_block_deaf.analysis_part_02_metadata.thresholds(n_STC, :)), 2));     
    end
end

%% all uLEDs
% hearing
for n_STC = 1:size(all_uLEDs.analysis_part_02_metadata.dprime_cumsum, 3)
    max_resp_all_uLEDs(n_STC) = max(max(all_uLEDs.analysis_part_02_metadata.dprime_cumsum(:, :, n_STC)));
    thresholds_all_uLEDs(n_STC) = min(all_uLEDs.analysis_part_02_metadata.thresholds(n_STC, :));
    active_electrodes_all_uLEDs(n_STC) = sum(~isnan(all_uLEDs.analysis_part_02_metadata.thresholds(n_STC, :)), 2); 
end

% deaf
for n_STC = 1:size(all_uLEDs_deaf.analysis_part_02_metadata.dprime_cumsum, 3)
    max_resp_all_uLEDs_deaf(n_STC) = max(max(all_uLEDs_deaf.analysis_part_02_metadata.dprime_cumsum(:, :, n_STC)));
    thresholds_uLEDs_deaf(n_STC) = min(all_uLEDs_deaf.analysis_part_02_metadata.thresholds(n_STC, :));
    active_electrodes_all_deaf(n_STC) = sum(~isnan(all_uLEDs_deaf.analysis_part_02_metadata.thresholds(n_STC, :)), 2); 
end

% hearing sacrificed
for n_STC = 1:size(all_uLEDs_sacrificed.analysis_part_02_metadata.dprime_cumsum, 3)
    max_resp_all_uLEDs_sacrificed(n_STC) = max(max(all_uLEDs_sacrificed.analysis_part_02_metadata.dprime_cumsum(:, :, n_STC)));
    thresholds_uLEDs_sacrificed(n_STC) = min(all_uLEDs_sacrificed.analysis_part_02_metadata.thresholds(n_STC, :));
    active_electrodes_sacrificed(n_STC) = sum(~isnan(all_uLEDs_sacrificed.analysis_part_02_metadata.thresholds(n_STC, :)), 2); 
end

% deaf sacrificed
for n_STC = 1:size(all_uLEDs_sacrificed_deaf.analysis_part_02_metadata.dprime_cumsum, 3)
    max_resp_all_uLEDs_sacrificed_deaf(n_STC) = max(max(all_uLEDs_sacrificed_deaf.analysis_part_02_metadata.dprime_cumsum(:, :, n_STC)));
    thresholds_uLEDs_sacrificed_deaf(n_STC) = min(all_uLEDs_sacrificed_deaf.analysis_part_02_metadata.thresholds(n_STC, :));
    active_electrodes_sacrificed_deaf(n_STC) = sum(~isnan(all_uLEDs_sacrificed_deaf.analysis_part_02_metadata.thresholds(n_STC, :)), 2); 
end

% wildtype animals
for n_STC = 1:size(all_uLEDs_wildtype.analysis_part_02_metadata.dprime_cumsum, 3)
    max_resp_all_uLEDs_wildtype(n_STC) = max(max(all_uLEDs_wildtype.analysis_part_02_metadata.dprime_cumsum(:, :, n_STC)));
    thresholds_uLEDs_wildtype(n_STC) = min(all_uLEDs_wildtype.analysis_part_02_metadata.thresholds(n_STC, :));
    active_electrodes_wildtype(n_STC) = sum(~isnan(all_uLEDs_wildtype.analysis_part_02_metadata.thresholds(n_STC, :)), 2); 
end

% wildtype animals - deaf
for n_STC = 1:size(uLEDs_deaf_wildtype.analysis_part_02_metadata.dprime_cumsum, 3)
    max_resp_all_uLEDs_wildtype_deaf(n_STC) = max(max(uLEDs_deaf_wildtype.analysis_part_02_metadata.dprime_cumsum(:, :, n_STC)));
    thresholds_uLEDs_wildtype_deaf(n_STC) = min(uLEDs_deaf_wildtype.analysis_part_02_metadata.thresholds(n_STC, :));
    active_electrodes_wildtype_deaf(n_STC) = sum(~isnan(uLEDs_deaf_wildtype.analysis_part_02_metadata.thresholds(n_STC, :)), 2);
end

   
%% optical fiber
% hearing
for n_STC = 1:size(all_uLED_optical_fiber.analysis_part_02_metadata.dprime_cumsum, 3)
    max_resp_all_uLEDs_optical_fiber(n_STC) = max(max(all_uLED_optical_fiber.analysis_part_02_metadata.dprime_cumsum(:, :, n_STC)));
    thresholds_uLEDs_optical_fiber(n_STC) = min(all_uLED_optical_fiber.analysis_part_02_metadata.thresholds(n_STC, :));
    active_electrodes_fiber(n_STC) = sum(~isnan(all_uLED_optical_fiber.analysis_part_02_metadata.thresholds(n_STC, :)), 2);
end

% deaf
for n_STC = 1:size(all_uLED_optical_fiber_deaf.analysis_part_02_metadata.dprime_cumsum, 3)
    max_resp_all_uLEDs_optical_fiber_deaf(n_STC) = max(max(all_uLED_optical_fiber_deaf.analysis_part_02_metadata.dprime_cumsum(:, :, n_STC)));
    thresholds_uLEDs_optical_fiber_deaf(n_STC) = min(all_uLED_optical_fiber_deaf.analysis_part_02_metadata.thresholds(n_STC, :));
    active_electrodes_fiber_deaf(n_STC) = sum(~isnan(all_uLED_optical_fiber_deaf.analysis_part_02_metadata.thresholds(n_STC, :)), 2);
end




%% plot data
f0 = figure('color', [1 1 1]); 

s1 = subplot(1, 5, [1:2]); hold on; title('max response [d-prime]');
plot(0.8:0.4./(length(max_resp_indiv_uLEDs)-1):1.2, max_resp_indiv_uLEDs, 'bo', 'MarkerFaceColor', [222 235 247]./255, 'color', [222 235 247]./255);
plot(0.8:0.4./(length(max_resp_indiv_uLEDs_deaf)-1):1.2, max_resp_indiv_uLEDs_deaf, 'ro', 'MarkerFaceColor', 'r', 'color', 'r');
plot(1.8:0.4./(length(max_resp_block_uLEDs)-1):2.2, max_resp_block_uLEDs, 'bo', 'MarkerFaceColor', [166 189 219]./255, 'color', [166 189 219]./255);
plot(1.8:0.4./(length(max_resp_block_uLEDs_deaf)-1):2.2, max_resp_block_uLEDs_deaf, 'ro', 'MarkerFaceColor', 'r', 'color', 'r');
plot(2.8:0.4./(length(max_resp_all_uLEDs)-1):3.2, max_resp_all_uLEDs, 'bo', 'MarkerFaceColor', [67 162 202]./255, 'color', [67 162 202]./255);
plot(2.8:0.4./(length(max_resp_all_uLEDs_deaf)-1):3.2, max_resp_all_uLEDs_deaf, 'ro', 'MarkerFaceColor', 'r', 'color', 'r');
plot(3.8:0.4./(length(max_resp_all_uLEDs_optical_fiber)-1):4.2, max_resp_all_uLEDs_optical_fiber, 'bo', 'MarkerFaceColor', [0 0 0.9], 'color', [0 0 0.9]);
plot(3.8:0.4./(length(max_resp_all_uLEDs_optical_fiber_deaf)-1):4.2, max_resp_all_uLEDs_optical_fiber_deaf, 'ro', 'MarkerFaceColor', 'r', 'color', 'r');
plot(4.8:0.4./(length(max_resp_all_uLEDs_wildtype)-1):5.2, max_resp_all_uLEDs_wildtype, 'bo', 'MarkerFaceColor', [0.75 0.75 0.75], 'color', [0.75 0.75 0.75]);
plot(4.8:0.4./(length(max_resp_all_uLEDs_wildtype_deaf)-1):5.2, max_resp_all_uLEDs_wildtype_deaf, 'ro', 'MarkerFaceColor', 'r', 'color', 'r');
plot(5.8:0.4./(length(max_resp_all_uLEDs_sacrificed)-1):6.2, max_resp_all_uLEDs_sacrificed, 'ko', 'MarkerFaceColor', 'k');
plot(5.8:0.4./(length(max_resp_all_uLEDs_sacrificed_deaf)-1):6.2, max_resp_all_uLEDs_sacrificed_deaf, 'ro', 'MarkerFaceColor', 'r');

errorbar(1, mean([max_resp_indiv_uLEDs; max_resp_indiv_uLEDs_deaf]), std([max_resp_indiv_uLEDs,; max_resp_indiv_uLEDs_deaf]),  'color', 'k', 'LineWidth', 2);
errorbar(2, mean([max_resp_block_uLEDs; max_resp_block_uLEDs_deaf]), std(([max_resp_block_uLEDs; max_resp_block_uLEDs_deaf])),                            'color', 'k', 'LineWidth', 2);
errorbar(3, mean([max_resp_all_uLEDs, max_resp_all_uLEDs_deaf]), std(([max_resp_all_uLEDs, max_resp_all_uLEDs_deaf])),                                'color', 'k', 'LineWidth', 2);
errorbar(4, mean([max_resp_all_uLEDs_optical_fiber, max_resp_all_uLEDs_optical_fiber_deaf]), std([max_resp_all_uLEDs_optical_fiber, max_resp_all_uLEDs_optical_fiber_deaf]),      'color',  'k', 'LineWidth', 2);
errorbar(5, mean([max_resp_all_uLEDs_wildtype, max_resp_all_uLEDs_wildtype_deaf]), std([max_resp_all_uLEDs_wildtype, max_resp_all_uLEDs_wildtype_deaf]),                'color', 'k', 'LineWidth', 2);
errorbar(6, mean([max_resp_all_uLEDs_sacrificed, max_resp_all_uLEDs_sacrificed_deaf]), std([max_resp_all_uLEDs_sacrificed, max_resp_all_uLEDs_sacrificed_deaf]),            'color', 'k', 'LineWidth', 2);

grid on; box on; xlim([0 7]); ylim([0 6]);


s2 = subplot(1, 5, [3:4]); hold on; title('active electrodes');
plot(0.8:0.4./(length(active_electrodes_indiv)-1):1.2, active_electrodes_indiv, 'bo', 'MarkerFaceColor', [222 235 247]./255, 'color', [222 235 247]./255);
plot(0.8:0.4./(length(active_electrodes_indiv_deaf)-1):1.2, active_electrodes_indiv_deaf, 'ro', 'MarkerFaceColor', 'r', 'color', 'r');
plot(1.8:0.4./(length(active_electrodes_block)-1):2.2, active_electrodes_block, 'bo', 'MarkerFaceColor', [166 189 219]./255, 'color', [166 189 219]./255);
plot(1.8:0.4./(length(active_electrodes_block_deaf)-1):2.2, active_electrodes_block_deaf, 'ro', 'MarkerFaceColor', 'r', 'color', 'r');
plot(2.8:0.4./(length(active_electrodes_all_uLEDs)-1):3.2, active_electrodes_all_uLEDs, 'bo', 'MarkerFaceColor', [67 162 202]./255, 'color', [67 162 202]./255);
plot(2.8:0.4./(length(active_electrodes_all_deaf)-1):3.2, active_electrodes_all_deaf, 'ro', 'MarkerFaceColor', 'r', 'color', 'r');
plot(3.8:0.4./(length(active_electrodes_fiber)-1):4.2, active_electrodes_fiber, 'bo', 'MarkerFaceColor', [0 0 0.9], 'color', [0 0 0.9]);
plot(3.8:0.4./(length(active_electrodes_fiber_deaf)-1):4.2, active_electrodes_fiber_deaf, 'ro', 'MarkerFaceColor', 'r', 'color', 'r');
plot(4.8:0.4./(length(active_electrodes_wildtype)-1):5.2, active_electrodes_wildtype, 'bo', 'MarkerFaceColor', [0.75 0.75 0.75], 'color', [0.75 0.75 0.75]);
plot(4.8:0.4./(length(active_electrodes_wildtype_deaf)-1):5.2, active_electrodes_wildtype_deaf, 'ro', 'MarkerFaceColor', 'r', 'color', 'r');
plot(5.8:0.4./(length(active_electrodes_sacrificed)-1):6.2, active_electrodes_sacrificed, 'ko', 'MarkerFaceColor', 'k');
plot(5.8:0.4./(length(active_electrodes_sacrificed_deaf)-1):6.2, active_electrodes_sacrificed_deaf, 'ro', 'MarkerFaceColor', 'r');

errorbar(1, mean([active_electrodes_indiv; active_electrodes_indiv_deaf]), std(([active_electrodes_indiv; active_electrodes_indiv_deaf])),                            'color', 'k', 'LineWidth', 2);
errorbar(2, mean([active_electrodes_block; active_electrodes_block_deaf]), std(([active_electrodes_block; active_electrodes_block_deaf])),                            'color', 'k', 'LineWidth', 2);
errorbar(3, mean([active_electrodes_all_uLEDs, active_electrodes_all_deaf]), std(([active_electrodes_all_uLEDs, active_electrodes_all_deaf])),                               'color', 'k', 'LineWidth', 2);
errorbar(4, mean([active_electrodes_fiber, active_electrodes_fiber_deaf]), std([active_electrodes_fiber, active_electrodes_fiber_deaf]),      'color',  'k', 'LineWidth', 2);
errorbar(5, mean([active_electrodes_wildtype, active_electrodes_wildtype_deaf]), std([active_electrodes_wildtype, active_electrodes_wildtype_deaf]),                'color', 'k', 'LineWidth', 2);
errorbar(6, mean([active_electrodes_sacrificed, active_electrodes_sacrificed_deaf]), std([active_electrodes_sacrificed, active_electrodes_sacrificed_deaf]),            'color', 'k', 'LineWidth', 2);
grid on; box on; xlim([0 6]); ylim([0 35]);


s3 = subplot(1, 5, [5]); hold on; title('thresholds [mW]');

plot(0.8:0.4./(length(thresholds_all_uLEDs)-1):1.2, thresholds_all_uLEDs, 'bo', 'MarkerFaceColor', [67 162 202]./255, 'color', [67 162 202]./255);
plot(0.8:0.4./(length(thresholds_uLEDs_deaf)-1):1.2, thresholds_uLEDs_deaf, 'ro', 'MarkerFaceColor', 'r', 'color', 'r');
plot(1.8:0.4./(length(thresholds_uLEDs_optical_fiber)-1):2.2, thresholds_uLEDs_optical_fiber, 'bo', 'MarkerFaceColor', 'b');
plot(1.8:0.4./(length(thresholds_uLEDs_optical_fiber_deaf)-1):2.2, thresholds_uLEDs_optical_fiber_deaf, 'ro', 'MarkerFaceColor', 'r');




uLED_thresholds = [thresholds_all_uLEDs, thresholds_uLEDs_deaf]';
fiber_threshold = [thresholds_uLEDs_optical_fiber, thresholds_uLEDs_optical_fiber_deaf]';
boxplot_group(1:length(uLED_thresholds)) = 1;
boxplot_group(length(uLED_thresholds)+1:length(uLED_thresholds)+length(fiber_threshold)) = 2;
boxplot([uLED_thresholds; fiber_threshold], boxplot_group', 'Whisker', 5)

grid on; box on; xlim([0 3]); ylim([0 2.5]);


%% statistics for hearing vs deaf

[p, h] = ranksum(max_resp_indiv_uLEDs, max_resp_indiv_uLEDs_deaf)
[p, h] = ranksum(max_resp_block_uLEDs, max_resp_block_uLEDs_deaf)
[p, h] = ranksum(max_resp_all_uLEDs, max_resp_all_uLEDs_deaf)
[p, h] = ranksum(max_resp_all_uLEDs_optical_fiber, max_resp_all_uLEDs_optical_fiber_deaf)

[p, h] = ranksum(active_electrodes_indiv, active_electrodes_indiv_deaf)
[p, h] = ranksum(active_electrodes_block, active_electrodes_block_deaf)
[p, h] = ranksum(active_electrodes_all_uLEDs, active_electrodes_all_deaf)
[p, h] = ranksum(active_electrodes_fiber, active_electrodes_fiber_deaf)

%% threshold fiber vs uLED
[p, h] = ranksum([thresholds_all_uLEDs thresholds_uLEDs_deaf], [thresholds_uLEDs_optical_fiber, thresholds_uLEDs_optical_fiber_deaf])

%% statistics for increase in response strength
clear stimulation_mode
stimulation_mode(1:size([max_resp_indiv_uLEDs; max_resp_indiv_uLEDs_deaf], 1), 1) = cellstr('single');
stimulation_mode(length(stimulation_mode)+1:length(stimulation_mode)+size([max_resp_block_uLEDs; max_resp_block_uLEDs_deaf], 1), 1) = cellstr('block');
stimulation_mode(length(stimulation_mode)+1:length(stimulation_mode)+size([max_resp_all_uLEDs'; max_resp_all_uLEDs_deaf'], 1), 1) = cellstr('all');
stimulation_mode(length(stimulation_mode)+1:length(stimulation_mode)+size([max_resp_all_uLEDs_optical_fiber'; max_resp_all_uLEDs_optical_fiber_deaf'], 1), 1) = cellstr('fiber');
stimulation_mode(length(stimulation_mode)+1:length(stimulation_mode)+size([max_resp_all_uLEDs_wildtype'; max_resp_all_uLEDs_wildtype_deaf'], 1)) = cellstr('wt_all');

max_responses = [[max_resp_indiv_uLEDs; max_resp_indiv_uLEDs_deaf]; [max_resp_block_uLEDs; max_resp_block_uLEDs_deaf]; [max_resp_all_uLEDs'; max_resp_all_uLEDs_deaf']; [max_resp_all_uLEDs_optical_fiber'; max_resp_all_uLEDs_optical_fiber_deaf']; [max_resp_all_uLEDs_wildtype'; max_resp_all_uLEDs_wildtype_deaf']];

[p,t,stats] = anova1(max_responses,stimulation_mode);
[c,~,~,nms] = multcompare(stats)



%% statistics for increase in response width
clear stimulation_mode
stimulation_mode(1:size([active_electrodes_indiv; active_electrodes_indiv_deaf], 1), 1) = cellstr('single');
stimulation_mode(length(stimulation_mode)+1:length(stimulation_mode)+size([active_electrodes_block; active_electrodes_block_deaf], 1), 1) = cellstr('block');
stimulation_mode(length(stimulation_mode)+1:length(stimulation_mode)+size([active_electrodes_all_uLEDs, active_electrodes_all_deaf], 2), 1) = cellstr('all');
stimulation_mode(length(stimulation_mode)+1:length(stimulation_mode)+size([active_electrodes_fiber, active_electrodes_fiber_deaf], 2), 1) = cellstr('fiber');
stimulation_mode(length(stimulation_mode)+1:length(stimulation_mode)+size([active_electrodes_wildtype, active_electrodes_wildtype_deaf], 2), 1) = cellstr('wt_all');


active_LEDs = [[active_electrodes_indiv; active_electrodes_indiv_deaf]; [active_electrodes_block; active_electrodes_block_deaf]; [active_electrodes_all_uLEDs, active_electrodes_all_deaf]'; [active_electrodes_fiber, active_electrodes_fiber_deaf]'; [active_electrodes_wildtype, active_electrodes_wildtype_deaf]'];

[p,t,stats] = anova1(active_LEDs,stimulation_mode);
[c,~,~,nms] = multcompare(stats)




