% This script takes these .mat-files and creates a figure that includes the data of both datasets.

clear all; close all; clc;

um_per_octave_IC = 230.2; % from tonotopy analysis, median slope = 4.34 octaves/mm = 230.2 m per octave
um_per_octave_cochlea = 1380; % from literature reference

electrode_spacing = 50; % in micrometer

load('tonotopy_indiv'); load('tonotopy_block');

f1 = figure('color', [1 1 1], 'Position', [400 100 300 400]); hold on;

plot(data_individual.stimsites, data_individual.BEs, 'mo');
plot(data_block.stimsites, data_block.BEs, 'co');


% adjust figure settings
set(gca,'Ydir','reverse'); grid on; box on;

% plot some lines in order to help for orientation in the figure. max/min +/- 500
% on the x-axis and max/min +/- 2 on the y axis ensure that all data points are visible.
plot([min([data_individual.stimsites; data_block.stimsites])-500 max([data_individual.stimsites; data_block.stimsites])+500], [0 0], 'r'); 
xlim([min([data_individual.stimsites; data_block.stimsites])-500 max([data_individual.stimsites; data_block.stimsites])+500]);
plot([0 0],  [min([data_individual.BEs; data_block.BEs])-2 max([data_individual.BEs; data_block.BEs])+2], 'r'); 
ylim([min([data_individual.BEs; data_block.BEs])-2 max([data_individual.BEs; data_block.BEs])+2]); 

ylabel('relative BE'); xlabel('relative stimulus location [\mum]')



p = polyfit(data_individual.stimsites, data_individual.BEs, 1); x = sort(data_individual.stimsites); 
y = (p(1).*x)+p(2); plot(x, y, 'm--')   

p = polyfit(data_block.stimsites, data_block.BEs, 1); x = sort(data_block.stimsites); 
y = (p(1).*x)+p(2); plot(x, y, 'c--')   


[R, P] = corrcoef([data_individual.stimsites, data_individual.BEs]);
text(2000, -9, ['r = ' num2str(R(2))], 'color', 'm')
text(2000, -8, ['p = ' num2str(P(2))], 'color', 'm')

[R, P] = corrcoef([data_block.stimsites, data_block.BEs]);
text(2000, -6, ['r = ' num2str(R(2))], 'color', 'c')
text(2000, -5, ['p = ' num2str(P(2))], 'color', 'c')


% as a reference, plot the tonotopy based on acoustic stimulation 
plot(3*um_per_octave_cochlea*[-1, 1], 3*[-1,1]*um_per_octave_IC./electrode_spacing , 'b-') % correct for electrode spacing


