% This script reads in the spectral spread data plot the data, 
% and perform an ANOVA with posthoc multiple comparison test to check for differences 
% between implants of different LED-pitch. 

clear all; clc; close all;

data_block = load('spectral_spread_uLED_block.mat');

% general parameters
% reference data from Dieter et al, Nat Comm 2019
bw_acoustic = [184 293 356 455];
bw_opto_fiber =  [214  394  610  792]; 
bw_eStim_mono = [411 975 1365 1453];
bw_eStim_bi = [144 845 1247 1462];


% plotting
f1 = figure('color', [1 1 1]);  hold on;
% spectral spread at dprime values 1.5, 2, 2.5 and 3 (index 1 to 4 in data_by_oCI_pitch)
plot(data_block.data.dprime_values(1)-0.025:0.05./(size(data_block.data.band_widths_100, 1)-1):data_block.data.dprime_values(1)+0.025, data_block.data.band_widths_100(:, 1), 'bo', 'color', [166 189 219]./255,'MarkerFaceColor', [166 189 219]./255)
plot(data_block.data.dprime_values(2)-0.025:0.05./(size(data_block.data.band_widths_100, 1)-1):data_block.data.dprime_values(2)+0.025, data_block.data.band_widths_100(:, 2), 'bo', 'color', [166 189 219]./255,'MarkerFaceColor', [166 189 219]./255)
plot(data_block.data.dprime_values(3)-0.025:0.05./(size(data_block.data.band_widths_100, 1)-1):data_block.data.dprime_values(3)+0.025, data_block.data.band_widths_100(:, 3), 'bo', 'color', [166 189 219]./255,'MarkerFaceColor', [166 189 219]./255)
plot(data_block.data.dprime_values(4)-0.025:0.05./(size(data_block.data.band_widths_100, 1)-1):data_block.data.dprime_values(4)+0.025, data_block.data.band_widths_100(:, 4), 'bo', 'color', [166 189 219]./255,'MarkerFaceColor', [166 189 219]./255)
errorbar(data_block.data.dprime_values(1), nanmean(data_block.data.band_widths_100(:, 1)), nanstd(data_block.data.band_widths_100(:, 1))./sqrt(length(data_block.data.band_widths_100(:, 1))), 'color', [166 189 219]./255, 'LineWidth', 2)
errorbar(data_block.data.dprime_values(2), nanmean(data_block.data.band_widths_100(:, 2)), nanstd(data_block.data.band_widths_100(:, 2))./sqrt(length(data_block.data.band_widths_100(:, 2))), 'color', [166 189 219]./255, 'LineWidth', 2)
errorbar(data_block.data.dprime_values(3), nanmean(data_block.data.band_widths_100(:, 3)), nanstd(data_block.data.band_widths_100(:, 3))./sqrt(length(data_block.data.band_widths_100(:, 3))), 'color', [166 189 219]./255, 'LineWidth', 2)
errorbar(data_block.data.dprime_values(4), nanmean(data_block.data.band_widths_100(:, 4)), nanstd(data_block.data.band_widths_100(:, 4))./sqrt(length(data_block.data.band_widths_100(:, 4))), 'color', [166 189 219]./255, 'LineWidth', 2)
plot(data_block.data.dprime_values,    nanmean(data_block.data.band_widths_100), 'color', [166 189 219]./255, 'LineWidth', 2)

plot(data_block.data.dprime_values(1)-0.025:0.05./(size(data_block.data.band_widths_250, 1)-1):data_block.data.dprime_values(1)+0.025, data_block.data.band_widths_250(:, 1), 'bo', 'color', [67 162 202]./255,'MarkerFaceColor', [67 162 202]./255)
plot(data_block.data.dprime_values(2)-0.025:0.05./(size(data_block.data.band_widths_250, 1)-1):data_block.data.dprime_values(2)+0.025, data_block.data.band_widths_250(:, 2), 'bo', 'color', [67 162 202]./255,'MarkerFaceColor', [67 162 202]./255)
plot(data_block.data.dprime_values(3)-0.025:0.05./(size(data_block.data.band_widths_250, 1)-1):data_block.data.dprime_values(3)+0.025, data_block.data.band_widths_250(:, 3), 'bo', 'color', [67 162 202]./255,'MarkerFaceColor', [67 162 202]./255)
plot(data_block.data.dprime_values(4)-0.025:0.05./(size(data_block.data.band_widths_250, 1)-1):data_block.data.dprime_values(4)+0.025, data_block.data.band_widths_250(:, 4), 'bo', 'color', [67 162 202]./255,'MarkerFaceColor', [67 162 202]./255)
errorbar(data_block.data.dprime_values(1), nanmean(data_block.data.band_widths_250(:, 1)), nanstd(data_block.data.band_widths_250(:, 1))./sqrt(length(data_block.data.band_widths_250(:, 1))), 'color', [67 162 202]./255, 'LineWidth', 2)
errorbar(data_block.data.dprime_values(2), nanmean(data_block.data.band_widths_250(:, 2)), nanstd(data_block.data.band_widths_250(:, 2))./sqrt(length(data_block.data.band_widths_250(:, 2))), 'color', [67 162 202]./255, 'LineWidth', 2)
errorbar(data_block.data.dprime_values(3), nanmean(data_block.data.band_widths_250(:, 3)), nanstd(data_block.data.band_widths_250(:, 3))./sqrt(length(data_block.data.band_widths_250(:, 3))), 'color', [67 162 202]./255, 'LineWidth', 2)
errorbar(data_block.data.dprime_values(4), nanmean(data_block.data.band_widths_250(:, 4)), nanstd(data_block.data.band_widths_250(:, 4))./sqrt(length(data_block.data.band_widths_250(:, 4))), 'color', [67 162 202]./255, 'LineWidth', 2)
plot(data_block.data.dprime_values,    nanmean(data_block.data.band_widths_250), 'color', [67 162 202]./255, 'LineWidth', 2)

xlim([1.25 3.25]); ylim([0 1600]); ylabel('spatial spread [\mum]'); xlabel('d-prime'); grid on; box on;
set(gca, 'XTick', 1.5:0.5:3)

% plot some reference data from Dieter et al, Nat Comm 2019
plot(data_block.data.dprime_values, bw_acoustic, 'k--', 'LineWidth', 2);
plot(data_block.data.dprime_values, bw_opto_fiber, 'b--', 'LineWidth', 2);
plot(data_block.data.dprime_values, bw_eStim_mono, 'r--', 'LineWidth', 2);
plot(data_block.data.dprime_values, bw_eStim_bi, 'y--', 'LineWidth', 2);


%% test for significance using repeated-measures anova

oCI_pitch(1:size(data_block.data.band_widths_100, 1), 1) = cellstr('100');
oCI_pitch(length(oCI_pitch)+1:length(oCI_pitch)+size(data_block.data.band_widths_250, 1), 1) = cellstr('250');

data_by_oCI_pitch = [data_block.data.band_widths_100; data_block.data.band_widths_250];

t = table(oCI_pitch,data_by_oCI_pitch(:,1),data_by_oCI_pitch(:,2),data_by_oCI_pitch(:,3),data_by_oCI_pitch(:,4),...
'VariableNames',{'modality','dprime_1_5','dprime_2','dprime_2_5','dprime_3'});


pitch_anova = table([1 2 3 4]','VariableNames',{'Measurements'});
rm = fitrm(t,'dprime_1_5-dprime_3~modality','WithinDesign',pitch_anova);
ranovatbl = ranova(rm);


%% test for significance using anova
% spatial spread at dprime values 1.5, 2, 2.5 and 3 (index 1 to 4 in data_by_oCI_pitch)
disp("\nComparing spectral spread at  d prime value of 1.5")
[p,t,stats] = anova1(data_by_oCI_pitch(:,1),oCI_pitch); [c,~,~,nms] = multcompare(stats)

disp("\nComparing spectral spread at  d prime value of 2.0")
[p,t,stats] = anova1(data_by_oCI_pitch(:,2),oCI_pitch); [c,~,~,nms] = multcompare(stats)

disp("\nComparing spectral spread at  d prime value of 2.5")
[p,t,stats] = anova1(data_by_oCI_pitch(:,3),oCI_pitch); [c,~,~,nms] = multcompare(stats)

disp("\nComparing spectral spread at  d prime value of 3.0")
[p,t,stats] = anova1(data_by_oCI_pitch(:,4),oCI_pitch); [c,~,~,nms] = multcompare(stats)
